@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
     layout checkerboard animate
     chess checkers conway
     calculator dk shroom
-    banner
+    calendar banner maze
 );
 
 use Clone;
@@ -33,7 +33,9 @@ sub calculator      { Spreadsheet::HTML::Presets::calculator(       @_ ) }
 sub chess           { Spreadsheet::HTML::Presets::chess(            @_ ) }
 sub checkers        { Spreadsheet::HTML::Presets::checkers(         @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
+sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
 sub animate         { Spreadsheet::HTML::Presets::animate(          @_ ) }
+sub maze            { Spreadsheet::HTML::Presets::maze(             @_ ) }
 sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
 sub dk              { Spreadsheet::HTML::Presets::dk(               @_ ) }
 sub shroom          { Spreadsheet::HTML::Presets::shroom(           @_ ) }
@@ -314,6 +316,8 @@ sub _expand_code_or_hash {
     return ( $cdata, $attr );
 }
 
+sub _range {grep!(($_-$_[0])%($_[2]||1)),$_[0]..$_[1]}
+
 
 1;
 
@@ -328,12 +332,12 @@ Spreadsheet::HTML - Just another HTML table generator.
 
     $data = [ [qw(a1 a2 a3)], [qw(b1 b2 b3)], [qw(c1 c2 c3)] ];
 
-    $table = Spreadsheet::HTML->new( data => $data, indent => "\t" );
-    print $table->portrait;
-    print $table->landscape;
+    $generator = Spreadsheet::HTML->new( data => $data, indent => "\t" );
+    print $generator->portrait;
+    print $generator->landscape;
 
     # load from files (first table found)
-    $table = Spreadsheet::HTML->new( file => 'data.xls', cache => 1 );
+    $generator = Spreadsheet::HTML->new( file => 'data.xls', cache => 1 );
 
     # non OO
     use Spreadsheet::HTML qw( portrait landscape );
@@ -433,11 +437,15 @@ with little to no additional coding.
 
 =item * C<calculator( jquery, %params )>
 
+=item * C<calendar( month, year, %params )>
+
 =item * C<checkerboard( colors, %params )>
 
-=item * C<animate( direction, %params )>
+=item * C<animate( direction, x, y, jquery, %params )>
 
-=item * C<banner( text, font, %params )>
+=item * C<banner( on, off, text, font, %params )>
+
+=item * C<maze( %params )>
 
 =item * C<chess( %params )>
 
