@@ -9,12 +9,14 @@ use Spreadsheet::HTML::Presets::Calculator;
 
 eval "use Color::Spectrum";
 our $NO_SPECTRUM = $@;
-
 eval "use JavaScript::Minifier";
 our $NO_MINIFY = $@;
-
 eval "use Text::FIGlet";
 our $NO_FIGLET = $@;
+eval "use Time::Piece";
+our $NO_TIMEPIECE = $@;
+eval "use List::Util";
+our $NO_LISTUTIL = $@;
 
 sub layout {
     my ($self,$data,$args);
@@ -102,7 +104,7 @@ sub banner {
         eval {
             @banner = Text::FIGlet
                 ->new( -d => $args->{dir}, -f => $args->{emboss} ? 'block' : 'banner' )
-                ->figify( -A => uc( $args->{text} ) );
+                ->figify( -A => uc( $args->{text} ), -w => 9999 );
         };
 
         if (@banner) {
@@ -119,6 +121,8 @@ sub banner {
                             push @cells, ( $key => { style => { 'background-color' => $off } } );
                         } elsif ($line[$col] eq '_') {
                             push @cells, ( $key => { style => { 'background-color' => $off, 'border-bottom' => "1px solid $on" } } );
+                        } elsif ($args->{flip}) {
+                            push @cells, ( $key => { style => { 'background-color' => $off, 'border-right' => "1px solid $on" } } );
                         } else {
                             push @cells, ( $key => { style => { 'background-color' => $off, 'border-left' => "1px solid $on" } } );
                         }
@@ -140,6 +144,92 @@ sub banner {
     return $table;
 }
 
+sub maze {
+    no warnings;
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
+    my @cells = ();
+    unless ($NO_LISTUTIL) {
+
+        my $height = 20;
+        my $width  = 16;
+        if ($args->{fill}) {
+            ($height,$width) = $args->{fill} =~ /^(\d+)\D(\d+)$/;
+            delete $args->{fill};
+        }
+        push @cells, ( fill => "${height}x${width}" );
+
+        my $off    = $args->{off}    || 'white';
+        my $on     = $args->{on}     || 'black';
+
+        my (@grid,@stack);
+        for my $h (0 .. $height - 1) {
+            $grid[$h] = [ map {
+                x     => $_, y => $h,
+                walls => [1,1,1,1], # W S E N
+            }, 0 .. $width - 1 ];
+        }
+
+        my %neighbor = ( 0 => 2, 1 => 3, 2 => 0, 3 => 1 );
+        my $visited = 1;
+        my $curr = $grid[rand $height][rand $width];
+        while ($visited < $height * $width) {
+            my @neighbors;
+            for (
+                [ 3, $grid[ $curr->{y} - 1 ][ $curr->{x} ] ], # north
+                [ 2, $grid[ $curr->{y} ][ $curr->{x} + 1 ] ], # east
+                [ 1, $grid[ $curr->{y} + 1 ][ $curr->{x} ] ], # south
+                [ 0, $grid[ $curr->{y} ][ $curr->{x} - 1 ] ], # west
+            ) { push @neighbors, $_ if List::Util::sum( @{ $_->[1]->{walls} } ) == 4 }
+
+            if (@neighbors) {
+                my ($pos,$cell) = @{ $neighbors[rand @neighbors] };
+                $curr->{walls}[$pos] = 0;
+                $cell->{walls}[$neighbor{$pos}] = 0;
+                push @stack, $curr;
+                $curr = $cell;
+                $visited++;
+            } else {
+                $curr = pop @stack;
+            }
+            @neighbors = ();
+        }
+
+        my %style_map = (
+           0 => 'border-left', 
+           1 => 'border-bottom', 
+           2 => 'border-right', 
+           3 => 'border-top', 
+        );
+
+        for my $row (0 .. $#grid) {
+            for my $col (0 .. @{ $grid[$row] }) {
+                my $key = sprintf '-row%scol%s', $row, $col;
+                my %style = ( 'background-color' => $off );
+                for (0 .. $#{ $grid[$row][$col]{walls} } ) {
+                    $style{$style_map{$_}} = "2px solid $on" if $grid[$row][$col]{walls}[$_]; 
+                } 
+                push @cells, ( $key => { height => '20px', width => '20px', style => {%style} } );
+            }
+        }
+    }
+
+    my @args = (
+        @_,
+        @cells,
+        matrix   => 1,
+        tgroups  => 0,
+        flip     => 0,
+        theta    => 0,
+        headless => 0,
+    );
+
+    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+    return $table;
+}
+
 sub calculator {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -240,6 +330,50 @@ sub conway {
     return $js . $table;
 }
 
+sub calendar {
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
+    my @args;
+    unless ($NO_TIMEPIECE) {
+        my $time = Time::Piece->strptime(
+            join( '-', 
+                $args->{month} || (localtime)[4]+1,
+                $args->{year}  || (localtime)[5]+1900,
+            ), '%m-%Y'
+        );
+        my $first = $time->wday;
+        my $last  = $time->month_last_day;
+        my @flat  = ( 
+            (map Time::Piece->strptime($_,"%d")->day, 4 .. 10),
+            ('') x ($first - 1),
+            1 .. $last
+        );
+        
+        push @args, [
+            map [ @flat[$_ .. $_ + 6] ],
+            Spreadsheet::HTML::_range( 0, $#flat, 7 )
+        ];
+
+        my $caption = join( ' ', $time->fullmonth, $time->year );
+        if ($args->{animate}) {
+            $caption = qq{<p>$caption</p><button id="toggle" onClick="toggle()">Start</button>};
+        }
+
+        my $attr = { style => { 'font-weight' => 'bold' } };
+        if ($args->{caption} and ref $args->{caption} eq 'HASH') {
+            ($attr) = values %{ $args->{caption} };
+        }
+
+        push @args, ( caption => { $caption => $attr } );
+    }
+
+    unshift @args, @_; 
+
+    return $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+}
+
 sub checkers {
     my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
 
@@ -496,7 +630,8 @@ These methods are not meant to be called from this package.
 Instead, use the Spreadsheet::HTML interface:
 
   use Spreadsheet::HTML;
-  my $table = Spreadsheet::HTML->new( data => [[1],[2]] );
+  my $generator = Spreadsheet::HTML->new( data => [[1],[2]] );
+  print $generator->layout();
 
   # or
   use Spreadsheet::HTML qw( layout );
@@ -540,7 +675,7 @@ Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
 via L<Javascript::Minifier> if it is installed.
 
-=item * C<banner( dir, text, emboss, on, off, %params )>
+=item * C<banner( dir, text, emboss, on, off, fill, %params )>
 
 Will generate and display a banner using the given C<text> in the
 'banner' font. Set C<emboss> to a true value and the font 'block'
@@ -550,7 +685,7 @@ You Must have L<Text::FIGlet> installed in order to use this preset.
 
   banner( dir => '/path/to/figlet/fonts', text => 'HI', on => 'red' )
 
-=item * C<conway( on, off, fade, interval, jquery, %params )>
+=item * C<conway( on, off, fill, fade, interval, jquery, %params )>
 
 Game of life. From an implementation i wrote back in college.
 
@@ -582,6 +717,18 @@ Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
 via L<Javascript::Minifier> if it is installed.
 
+=item * C<calendar( month, year, %params )>
+
+Generates a static calendar. Defaults to current month and year.
+
+  calendar( month => 7, year, 2015 )
+
+=item * C<maze( on, off, fill, %params )>
+
+Generates a static maze.
+
+  maze( fill => '10x10', on => 'red', off => 'black' ) 
+
 =item * C<checkers( %params )>
 
 Generates a static checkers game board (US).
